from __future__ import annotations

from tcsoa.base import TcBoClass
from dataclasses import dataclass


@dataclass(unsafe_hash=True)
class Ac0ActiveCollabDataProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Ac0Comment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Ac0CommentStatsRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Ac0Conversation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Ac0ConversationSrcRel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Ac0SubscriptionRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Ac0UserFeedRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0ArrangementProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0AutoBookmark(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0Connection(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0ContextProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0EffectivityProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0Element(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0FullTextSearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0Interface(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0MarkupElement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0MarkupForLevelProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0MarkupProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0OverrideDatasetProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0BOMIndexAdminData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0PositionedElement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0ProductContextInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0ProductFeature(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0SavedBookmark(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0SavedQueryProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0SubstitutesProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0ViewTypeProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0ZoneProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0BookmarkData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0BookmarkNavigationData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0BookmarkProductData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0BookmarkSubsetData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0CSIDsToElementsProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0ClosureRulesProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awb0ConditionalElement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Aut0ProjectProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0AWCExternalSystemObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0AdvancedQueryCriteria(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0GatewayTileRel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0IdContextListOfValues(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0InboxProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0MySearchFolder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0NumericSearchFilter(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0ObjectSetRowProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0PALProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0QuickSearchLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0RecentObjectsProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0ReferencesProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0AdvancedSearchInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0RelationProxyObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0RelationsCustomLOVBO(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0ResourceProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0RevRuleLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0SavedQuerySearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0SavedSearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0SearchFolder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0SearchFolderProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0SearchFolderShareRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0SignoffsProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0AdvancedSearchLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0StringSearchFilter(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0TablePropertyProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0TaskSearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0Tile(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0TileCollection(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0TileProxy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0TileTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0TraceLinkProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0TraceLinkProxyObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0TraceabilityMatrix(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0AlternatesProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0TypeSearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0UserAssignment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0VNCProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0WorkflowReportProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0WorkflowTemplateLOVBO(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0XRTObjectSet(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0XRTObjectSetColumn(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0XRTObjectSetRow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ClientContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0CollabDataProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Selection(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0DateSearchFilter(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0FavoritesProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0FullTextSavedSearch(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awp0FullTextSearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awv0BOMIndexPSProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awv0BookmarkVisData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Awv0ProductStructureProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAdmissibility(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAdmissibilityThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsCompoundFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0CompiledRuleSet(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ConfContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ConfigCriteriaEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ConfigCriteriaKey(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ConfigCriteriaThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ConfigModuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ConfigurationModule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ConfiguratorCriteria(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ConfiguratorPerspective(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0DefaultRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsCompoundOptionValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0DefaultRuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0Dictionary(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0EFFIntentThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0EffFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0EffectivityExprBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0EffectivityFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0EffectivityIntent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ExceptionRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ExceptionRuleThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ExcludeRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsCompoundValueFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ExcludeRuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ExternalOperation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ExternalOperationBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FamilyAvailability(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FamilyGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FamilyGroupThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FeasibilityRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FeasibilityRuleThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0Feature(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FeatureFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsCompoundValueThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FeatureFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FeatureSet(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FeatureSetThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0FeatureThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0IncludeRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0IncludeRuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0LiteralFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0LiteralOptionValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0LiteralValueFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0LiteralValueThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsConfigCriteriaThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0OptionValueAvailability(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0PackageFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0PackageOptionFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0PackageOptionValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0PackageRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0PackageRuleThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0PackageValueThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ProdModelFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ProductItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ProductLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsConfigModuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ProductLineFamThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ProductLineFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ProductLineThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ProductModel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ProductModelFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ProductModelThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0RangeExpression(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SearchCursor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SearchDefinition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SearchGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsConfigurationModule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SearchJoin(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SearchResultType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SearchSavedQuery(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SearchSlctContent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SearchTraversal(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SumModelFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SummaryFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SummaryModel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SummaryModelFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SummaryModelThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsConfiguratorCriteria(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SummaryOptionFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SummaryOptionValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0SummaryValueThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantCriteria(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantCriteriaBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantCriteriaExpr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantCriteriaThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantExpSection(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantExprBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantExpression(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsConfiguratorWSO(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantExpressionGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantExpressionSet(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantExpressionTerm(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0VariantSubExpression(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsConfiguratorWSOThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAllocation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsConstraintRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsConstraintRuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsDefaultRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsDefaultRuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsEFFIntentThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsEffFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsEffectivityFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsEffectivityIntent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsExceptionRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsExceptionRuleThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAllocationThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsExcludeRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsExcludeRuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsExternalOperBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsExternalOperation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFamilyAvailability(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFamilyGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFamilyGroupThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFeasibilityRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAssociation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFeasibilityRuleThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFeature(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFeatureFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFeatureFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFeatureSet(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFeatureSetThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFeatureThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsFreeFormRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsIncludeRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsIncludeRuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAssociationThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsLiteralFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsLiteralOptionValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsLiteralValueFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsLiteralValueThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsModel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsModelFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsModelFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsModelScopedWSO(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsModelScopedWSOThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsModelThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAvailability(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsOptionFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsOptionFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsOptionValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsOptionValueThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsPackageFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsPackageOptionFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsPackageOptionValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsPackageRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsPackageRuleThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsPackageValueThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAvailabilityRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsProdModelFamilyThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsProductLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsProductLineFamThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsProductLineFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsProductLineThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsProductModel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsProductModelFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsProductModelThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsRuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAvailabilityRuleThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsSumModelFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsSummaryFamilyThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsSummaryModel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsSummaryModelFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsSummaryModelThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsSummaryOptionFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsSummaryOptionValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsSummaryValueThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsValidationRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsValidationRuleThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsAvailabilityThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsValueAvailability(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AbsValueThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0Allocation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AllocationThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AppVariantCriteriaExpr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0ApplicationVariantExp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AvailabilityRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AvailabilityRuleThrd(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cfg0AvailabilityThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Analyst(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMEdit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CMSolutionToImpacted(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeImplementationBoard(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeItemRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeNotice(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeNoticeRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeRequest(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeRequestRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeReviewBoard(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeSpecialist1(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMSupersedure(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeSpecialist2(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeSpecialist3(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cm0ActionItemRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cm0ChangeContributors(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cm0EffectivityExprBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cm0GlobalChangeContextsLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cm0GnWorkOrder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cm0GnWorkOrderRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cm0HasProposal(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cm0ProposedImpactedObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CMHasImpactedItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Cm0RemovedLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GnChangeNotice(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GnChangeNoticeRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GnChangeRequest(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GnChangeRequestRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GnProblemReport(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GnProblemReportRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProblemReport(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProblemReportRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CMHasProblemItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Requestor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CMHasSolutionItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CMHasWorkBreakdown(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CMImplements(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CMReferences(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CMRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Dma1PrintConfigCustomLOVBO(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Dma1PrintConfigRuntime(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ADA_License(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccArchRef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccNote(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AurvirForIncrChange(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Authentication(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AuthorizationRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BMOperation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMDerivedDefault(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMFixedDefault(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMOption(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMOptionIndexExpr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMRuleCheck(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccPosRef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMVariantExprBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMVariantRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOMWindow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOPWindow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOSLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BOSWindow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BillRate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BomChange(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BoundingBox(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BoundingMultiBox(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccQuantity(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BulkCopyInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BulkData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BulkInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BulkSaveInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BusinessContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BusinessElement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BusinessObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BusinessObjectInterface(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BusinessRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BusinessRuleDescriptor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccSeqNo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEAnalysis(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEAnalysisRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEAttachmentWindow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEBCItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEBCItemRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEConnItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEConnItemRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEGeometry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEGeometryRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccSource(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEItemRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAELoadItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAELoadItemRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEModel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEModelRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEResult(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CAEResultRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CCObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMDateEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMEndItemEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMGroupEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMGroupItemTypeEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMLatestEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMOverrideEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMPreciseEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMRuleEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMStatusEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMUnitNoEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFMWorkingEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CFM_date_info(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccUCC(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CPBriefRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CPMarketingBriefRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CPThemeBoardRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CadAttrMappingDefPart(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CadAttrMappingDefPartGRM(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CadAttrMappingDefPartICS(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CadAttrMappingDefPartNR(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CadAttrMappingDefPartProp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CadAttrMappingDefPartSNoff(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CadAttrMappingDefinition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccUOM(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CallbackFunction(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CfgAbsOccAttachmentLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CfgActivityLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CfgAttachmentLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CfgAttachmentWindow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CfgBlAttachmentLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ChangeTypeData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ClientDataMaster(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CloneStructureCADDependencyData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CloneStructureTopLineData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccUsgPartID(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ClosureRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CompanyContact(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CompanyLocation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ComponentRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CondValAgent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CondValAgentRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CondValData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CondValDataRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CondValResult(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Condition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccUsgProduct(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ConditionParameter(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ConditionSignature(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ConfigurationCNF(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ConfigurationContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ConfigurationExprLiteral(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ConfigurationFamily(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Constant(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ConstantAttach(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ConstantChoice(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ContactInCompany(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccChildItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccVariantCondition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CostValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CreateInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CrfQuerySource(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DCt_GraphicPriority(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DCt_Language(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DataType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DataTypeRef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Dataset(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DatasetType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DecisionTable(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccViewQualifier(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DeepCopyData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DeepCopyRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DerivedObj(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Design(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Design_Revision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DesignReq(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DesignReqRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DgtSignatureByUserRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Discipline(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DispatcherRequest(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccXform(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DispatcherServiceArgument(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DispatcherServiceConfig(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DistributionList(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Document(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class DocumentRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Drawing(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Drawing_Revision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMAcknowledgeTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMAcknowledgeTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMAction(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccurrence(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMAddStatusTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMAddStatusTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMAssignmentList(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMBRHandler(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMBusinessRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMConditionTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMConditionTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMDoTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMDoTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMHandler(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Allocation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMJob(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMNotifyTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMNotifyTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMOrTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMOrTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMPerformSignoffTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMPerformSignoffTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMResourceList(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMReviewTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMReviewTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AllocationData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMRouteTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMRouteTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMSelectSignoffTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMSelectSignoffTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMSignoffProfile(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMValidateTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EPMValidateTaskTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Effectivity(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AllocationLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EffectivityMapping(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EffectivityMode(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EncryptionKey(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Envelope(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class EventTypeMapping(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ExportTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ExportTemplateRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ExportedProxyLink(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Extension(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ExtensionDescriptor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AllocationMap(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ExtensionPoint(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ExternalAttribute(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ExternalDataSource(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ExternalDataType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class FND_TraceLink(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class FileTOC(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Filter(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbsActionItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbsAlternateGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbsBranchRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AllocationMapRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbsInterchangeableGrp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbsSubstituteGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbstractCommand(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbstractMarkupSpace(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbstractNote(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbstractNoteRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbstractOcc(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbstractOccRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbstractPersistentProxy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AbstractProxyLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AllocationWindow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AdminGSIdentity(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AlgebraicFormula(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AlignedDesign(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AlignedDesignsProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AlignedPart(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AlignedPartsProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AppSession(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ApprSchCriteriaFormAttr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ApprSchCriteriaScpAttr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AttrExchangeConfig(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Anchor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AuditDefProperty(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AuditDefinition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AuditLink(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0AuditLog(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BMIDEDeployArchive(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BMIDEProjectBackup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BMIDEResource(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BOMLineLite(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BaseProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BomLineSearchCriteria(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppExtensionPoint(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BopFastener(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BopFastenerGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Branch(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BranchContent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BranchToBranchRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BuildingBlockBOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BvrFastener(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0BvrFastenerGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0CFMBranchEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0CFMGroupOccTypeEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppExtensionRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ChangeContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Client(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ClientScope(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ClientSessionInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0CloneData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0CmdConfigRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ColumnConfig(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ColumnConfiguration(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ColumnDef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ColumnOrderRel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppExtensionRuleType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Command(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0CommandCollection(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ConcatenationRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ConditionHelper(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ConfigContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ConsentRel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ContextMenuSuppRuleXML(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ContextSpecificID(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Cparam(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0CreateInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppGroupBOPLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0CustomNote(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0CustomNoteRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0CustomUserProfile(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DeepCopyData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DeployVersion(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DesignReqBOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DesignToBomRelInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DesignToBomRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DetailedMessage(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Diagram(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppInterface(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DiagramRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DiagramRules(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DiagramSnapshot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DiagramTmpl(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DiagramTmplRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DiagramTmplRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DigitalSignature(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DisclosedModelViewData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DisclosedViewList(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0DisclosingObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppInterfaceType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EPMTaskProxyLink(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EditContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EffectivityCritValidatn(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EffectivityCriteriaExpr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EffectivityExprBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EffectivityExpression(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EmailPollSessionDigest(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EmailPollingConfig(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EmailResponseRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0EventTypeMapping(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Appearance(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0FasnGroupHardwareRow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0FileAccessAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0FilterRecipe(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0FormulaConversion(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0FunctionalBOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0GDPRConsent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0GDPRConsentRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0GeneralAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0GenericConversionRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0GetChildrenProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppearanceAttr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0GnWOTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0GnWOTaskRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0GroupMemberLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0HTMLObjTmplRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Icon(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0IdGenerationRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0IdGenerationRuleAttach(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0IncludedLODef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0IncludedLODescriptor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ItemLineLite(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppearanceAttrDefinition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0JoinedPartsTableRow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0KeyValuePair(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LOCompoundPropDef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LOFilterCriteria(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LOFilterCriteriaLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LOPropPresentations(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LOVDictionaryEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LOVStringSpecElemTypes(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LicenseBundlesDynLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LicenseChangeAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccDataQualifier(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppearanceAttrMapping(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LicenseExportAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LicenseInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LicenseServer(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LicenseUsage(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ListOfDestTypesLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ListOfMembersLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ListOfRelRefPropsLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ListOfSourcePropsLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ListOfValuesDynamic(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ListsCustomNotes(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppearanceCheckerPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ListsParamReqments(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LogicConn(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LogicConnRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LogicIntrfce(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LogicalBOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LogicalBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LogicalBlockRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LogicalObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LogicalObjectLOVBO(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LogicalObjectType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppearanceConfigContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0LoginLicenseInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0MMVCursor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0MUActionTypesLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0MUImpactedParents(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0MarkpointBulletinBoardMgr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Markup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0MarkupChange(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Message(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0MessageProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ModelReqBOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppearanceGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ModelViewPalette(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ModelViewProxy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0NXCMValDataResult(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0NXPartTable(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0NXValDataResult(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0NameCounterGroups(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0NameValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0NameValueDynLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0NotificationTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARAccessDlg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppearanceRoot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARAccessGroupsDynamic(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARAccessProjDynamic(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARAccessRolesDynamic(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARAccessUsersDynamic(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARConditionProp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARConditionPropDynamic(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARFunctionArgValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARFunctionArgValueLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OAROp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OAROpLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AppearanceTrackedItemInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARRuleAccessor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OARRuleAccessorLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ObjectStatus(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ObjectThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OccEffCutback(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OccEffValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0OrganizationAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0PSInstance(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ParamReqOcc(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ParamReqment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprHistoryDateEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ParamReqmentRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0PrivateKey(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ProductSessionData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Profiler(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0PropagationRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0PropertyDescriptor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0PropertyFormatter(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0PropertyFormatterAttach(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0PropertyRenderer(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0PropertyRendererAttach(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprHistoryEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ProxyAlignedLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ProxyBOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ProxyTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Qualification(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0QueryFolder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0RangeConversion(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0RecipeContainer(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0RecordColConversion(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0RecordConversion(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0RelevantBVR(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprHistoryUnitNoEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ReportProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ReqdQual(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0RequirementBOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SEBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SEBlockRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ScheduleAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ScheduleTaskProxyLink(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ScopedCNF(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SealantTableRow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SecondaryAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprItemRevOrder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SecurityAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ShapeRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SharedEffExprBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Snapshot3DVisibleLInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SpatialViewingLog(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0StaticTable(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0StructureAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0StructureContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SubscribeCriteriaConf(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SubscriptionTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccFlags(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprQueryAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0SubsetLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0TC_valdata_result(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0TableRow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0TaskPathNamesLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0TempAppSession(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0TraversalRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0TraversalSegment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0TypeSearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0UIConfigCollectionRel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0UIConfigOrderRel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprQueryAuditPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0UIConfiguration(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0UIConfigurationObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0UserDefaultGroupDynLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0UserHasQual(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0UserProjectsLOV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0UserSettingsLov(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ValDataResult(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ValidationHome(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ValidationReqBOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0ValueConversion(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprRevRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0VariantExprBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0VariantExpression(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Vis3DSnapshot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0VisioDiagram(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0VisioDiagramRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0VisioTmpl(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0VisioTmplRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0WSOThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0WhereConfiguredProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0WorkflowAudit(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprRevRelationDateEff(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0Workset(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0WorksetLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Fnd0WorksetRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Folder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Form(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class FullText(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class FunctionalityRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GDEBOPLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GDELine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GDELinkLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprRevRelationUnitEff(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GDEOccurrence(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GDEOccurrenceList(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GDETypeDefinition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GDEbvr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GMSMappingHolder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GSIdentity(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GeneralDesignElement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GeneralDesignElementLink(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GeneratedDataType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GlobalConstant(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteria(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GlobalConstantAttach(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GraphicOptionRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GraphicRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Group(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class GroupMember(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class HSM_Info(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class HSM_Policy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class HideTypeRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ICSRuntimeAttr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ICSRuntimeICOIdAttr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaAttribute(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IDCLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IDCWindow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IRDC(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IRDCDerNaming(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IRDCNaming(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IRDCRender(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IdContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IdContextRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IdDispRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IdDispRuleList(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaBoxZone(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IdDispRuleSpec(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Identifier(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanAction(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanActionHandler(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanAliasList(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanCompoundPropDef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanEvent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanEventType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanExportRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanFile(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanGRM(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanIDCreator(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanItemBOPLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanItemLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanPFF(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanParameters(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanQuery(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanReservation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanSubscription(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaInClass(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ImanVolume(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class IncrementalChangeElement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class InstalledTemplates(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Intent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Item(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ItemExportRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ItemIdRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ItemRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Library(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccGdeObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaMapAttr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class LineOfUsage(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ListOfValues(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ListOfValuesChar(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ListOfValuesDate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ListOfValuesDouble(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ListOfValuesFilter(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ListOfValuesInteger(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ListOfValuesString(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ListOfValuesTag(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEActivity(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaNamedZone(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEAppearanceGroupLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEAppearanceLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEAppearancePathNode(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEAppearancePathRoot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEAssemblyWindow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MECfgLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MECfgWindow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MENXObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEOP(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEOPRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaPlaneZone(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEOpTimeAnalysis(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEProcess(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEProcessPartition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEProcessRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEProcessTimeAnalysis(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEProductBOP(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEViewLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEWorkarea(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MEWorkareaRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ManagedRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaProximity(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MappedProperty(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MasterRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mdl0ApprCompositeSearch(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mdl0ApprSrchCrtClosure(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MediaTOC(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MetaEnum(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MetaEnumLiteral(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MetaException(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class MetaInterface(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0ApprSchCriteriaBIWAttr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaSavedQry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0ApprSchCriteriaEBOPAttr(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0AssociatedContainers(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrActivity(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrAlternativeScope(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrArcWeld(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrBOPWorkarea(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrBopArcWeld(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrBopManufacturingFeature(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrBopWeldPoint(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrCompOP(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSearchCriteriaSlctState(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrConstraint(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrContinuousJoinOperation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrDatum(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrDiscreteJoinOperation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrDynamicIPA(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrEBopContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrEquipment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrFlow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrFolder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrGenericBOP(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSetRootStatusPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrIPA(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrLibrary(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrLocalResourceLibrary(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrLogicalAssignment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrManufacturingFeature(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrMaterial(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrOperation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPLC(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPLP(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPart(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprSpatialUpdatePkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPartition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPlantBOP(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPlantEquipment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPlantPLC(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPlantResource(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPlantRobot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPlantSensor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrPrecedenceConstraint(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProcess(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProcessArea(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdBootstrapPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProcessContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProcessLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProcessPartition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProcessResource(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProcessStation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProdProgram(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProdProgramCol(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProdProgramDef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProductBOP(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProductLogicalAssign(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdByApprRootEffPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrProductVariant(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrReferenceFrame(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrResource(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrRobot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrScopeFlow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrSensor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrShdStudy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrSimStudy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrStep(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrStudy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccGrmAnchor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdByApprRootPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrToolRequirement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrWeldPoint(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0BvrWorkarea(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEAlternativeScope(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MECompOP(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEConstraint(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEDynamicIPA(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MELocResLib(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MELogicalAssignment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEMBOMRecipe(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdByApprRootRevPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEPLC(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEPlantBOP(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEPlantBOPRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEPositionDiagram(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEPrecedenceCons(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEProcAreaProdImageRel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEProcAreaRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MERobot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MESensor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEShdStudy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdByApprRootWorkingPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MESimStudy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEStep(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEStudy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0MEStudyRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0ProcResourceRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0SearchCriteriaAttribute(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0SearchCriteriaGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0StudyContextRel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Mfg0StudyLinkRel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Migration_Distribution(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdChangePkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Migration_Pending(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Migration_Policy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Migration_Report(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ModelReq(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ModelReqRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXAgent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXAgentRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXCMValData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXCMValDataRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXCheckMate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdChangedEffPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXCheckMateRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXRDDV(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXRDDVRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXRDDVValData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXRDDVValDataRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXValData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NXValDataRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NameCounter(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NameField(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NameRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdChangedRevsPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NameRulePattern(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NamedRevisionAnchor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NamedVariantExpression(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NextIdField(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class NoteType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ObjectMapping(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class OccurrenceAuditLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Operation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class OperationAttach(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class OperationInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdImportedRevsPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class OperationParameter(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class OperationTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class OverrideApproval(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PIEActionRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PLMAppUID(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class POM_application_object(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class POM_data_manager(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class POM_group(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class POM_imc(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class POM_member(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdIncrChangePkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class POM_object(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class POM_system_class(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class POM_user(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSAlternateList(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSAlternateSet(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSBOMView(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSBOMViewRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSConnection(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSConnectionRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSOccurrence(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdPreReleasedRevsPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSOccurrenceNotes(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSOccurrenceThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSOccurrenceType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSOption(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSOptionalItemList(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSSignal(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSSignalRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSSignalValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSViewType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PSXform(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdRevViewImpactsRoot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Paragraph(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Paragraph_Revision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ParameterInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Part(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Part_Revision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PartOcc(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Participant(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Person(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PrefixProperty(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PrimitiveDataType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccInstanceNo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdStructureChangePkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PrintConfiguration(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PrivateContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProgressData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProjectObjectRelation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProjectPreference(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProjectSmartFolder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProjectTeam(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PropRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PropertyBMOperation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PropertyConstant(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdWorkingPkg(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PropertyConstantAttach(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PropertyInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PropertyOperation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PropertySet(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProposedResponsibleParty(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProposedReviewer(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProxyLink(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProxyLinkEng(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProxyLinkRemoteWkf(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProxyLinkReq(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdaterAuditRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PseudoFolder(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PublicationAuditRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PublicationRecord(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PublishLink(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class PublishedObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class QSearchIndex(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class QSearchIndexUpdateEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RBFCell(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RBFExpression(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RBFInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdaterBgActivity(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RBFOutput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RBFParamDef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RBFRow(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RBFTableColumn(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RDVAutoNVE(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Range(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RecordObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Release(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReleaseStatus(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RemoteAppearance(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdaterCronEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RemoteAppearanceRoot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RemoteBOMLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RemoteObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReportDefinition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReportDesign(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReqBooleanExp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReqDoubleExp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReqExpression(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReqIntExp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReqNumberExp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ApprUpdaterEmail(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReqStringExp(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RequestObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Requirement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Requirement_Revision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RequirementSpec(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RequirementSpec_Revision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Reservation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ResourceAssignment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ResourcePool(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RevNextIdField(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Architecture(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ReviseInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RevisionAnchor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RevisionNameRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RevisionNameRuleAttach(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RevisionRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Role(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RoleInOwningGroup(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RollupTemplate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RollupTemplateCofMass(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RollupTemplateInertia(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ArchitectureRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RollupTemplateReference(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RollupTemplateSum(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RouteCurve(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RouteDisplay(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RouteLocation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RouteLocationRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RouteNode(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RoutePath(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RouteSegment(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class RuntimeBusinessObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ArroApprsHistoryEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SCTypeData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SFRInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SaveAsInput(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SavedQueryCriteria(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SavedSearch(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SchDeliverable(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SchMgtCostForm(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SchMgtCostFormStorage(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SchTaskDeliverable(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Schedule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ArroDateEffsHistoryEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ScheduleDeliverable(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ScheduleMember(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ScheduleRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ScheduleTask(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ScheduleTaskRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SchedulingFixedCost(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SearchCursor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SearchStructureContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ServiceInterface(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Signoff(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AbsOccName(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ArroHistoryEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SingleFileRecovery(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Snapshot(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SourceObj(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SpecElement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SpecElementRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class StorageMedia(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class StoredOptionSet(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class StoredOptionValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Struct(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class StructElement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ArroIncrChgRevsHistoryEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class StructureContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class StructureMap(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class StructureMapRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Supercedure(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class SystemStampConfiguration(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TCCalendar(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TCCalendarEvent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TCMPlmXml(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TCX_SCConfig(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TCX_SCNumber(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ArroUnitEffsHistoryEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TCX_SCSetValue(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TCX_SCType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TC_Program_Preferred_Items(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TC_Project(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TC_UserContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TC_Validation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TC_WorkContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Table(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableCell(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableCellBCD(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ArroValidRevsHistoryEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableCellDate(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableCellDouble(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableCellHex(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableCellInt(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableCellLogical(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableCellSED(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableCellString(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableDefinition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TableLabel(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TaskDeliverable(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AssemblyArrangement(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TaskDependency(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TaskExecutionFormInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TaskInbox(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TaskSchedulingFormInfo(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TaskType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TemplateDataType(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TimeSheetEntry(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Tool(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TraceLink(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TransferMode(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AssemblyArrangementAnchor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TransferOptionSet(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TransferPending(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TranslationOrderRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TranslatnDelvryRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TransltnOffice(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TransltnOfficeRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TypeBMOperation(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TypeCannedMethod(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TypeConstant(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class TypeConstantAttach(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AuditDefinition(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Typedef(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class UnitOfMeasure(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class UsageAuditLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class UsageOption(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class UsagePartNumber(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class User(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class UserSession(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class User_Inbox(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VM_Info(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VM_Policy(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AuditLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValDataRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValReqResult(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValToolAgent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValToolAgentRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValidationAgent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValidationAgentRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValidationData(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValidationMaster(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValidationMaster_Form(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AuditReport(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValidationParams(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValidationReq(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValidationReqRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ValidationResult(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Variant(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VariantExpression(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VariantExpressionBlock(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VariantExpressionEditor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VariantRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VariantRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class AurvirForChangedRev(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VerificationRule(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VisStructureContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class WeldPoint(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class WeldPointRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class WolfObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class WorkspaceObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class WorkspaceObjectThread(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class bldb0(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class icm0(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class smlb0(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Pca0ProductLineProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Pca0SavedVariantsProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Saw1DisciplineSearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Saw1ScheduleSearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Saw1TaskSearchProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BidPackage(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BidPackageContent(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VMRepresents(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Vendor(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VendorRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class VendorRole(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Vm0ExchangeLine(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Vm0PrtnrContractRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Vm0SupplierResponseObject(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Vm0VendorXChangeRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BidPackageLineItem(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class BidPackageRevision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CommercialPart(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class CommercialPart_Revision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class LineItemConfigContext(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ManufacturerPart(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ManufacturerPart_Revision(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class ProvidedFrom(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Vm1AssignedObjsDataProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Vm1VendorLocationProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass


@dataclass(unsafe_hash=True)
class Vm1VendorPartsProvider(TcBoClass):
    """
    System class - needs reverse engineering!
    """
    pass
